<?php
/**
*  Targetfirst.com
*
*  @author    Loic TCHING <loic.tching@targetfirst.com>
*  @copyright 2007-2020 Targetfirst
*  @license   https://www.targetfirst.com
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

class Targetfirst extends Module
{
    private $_html = '';
    private $_postErrors = array();

    public function __construct()
    {
        $this->name = 'targetfirst';
        $this->tab = 'front_office_features';
        $this->version = '1.0';
        $this->author = 'Target First';
        $this->module_key = 'ebc243d69ff4ffaaa4fc038c03cc8375';
        $this->url = 'https://www.watcheezy.net/deliver/targetfirst.js';
        
        $key = Configuration::get('WE_API_KEY');
        if (isset($key)) {
            $this->api_key = $key;
        }

        parent::__construct();

        $this->displayName = $this->l('Targetfirst');
        $this->description = $this->l('Targetfirst improve the conversion rate thanks to face to face online customer support.');
        $this->confirmUninstall = $this->l('Are you sure you want to delete these details?');

        if ((!isset($this->api_key))) {
            $this->warning = $this->l('An api key is needed');
        }
    }

    public function install()
    {
        if (!parent::install() || !$this->registerHook('displayFooter')) {
            return false;
        }
        return true;
    }

    public function uninstall()
    {
        if (!Configuration::deleteByName('WE_API_KEY') || !parent::uninstall()) {
            return false;
        }
        return true;
    }

    private function _postValidation()
    {
        if (Tools::isSubmit('btnSubmit')) {
            if (!Tools::getValue('key')) {
                $this->_postErrors[] = $this->l('The API key is required.');
            }
        }
    }

    private function _postProcess()
    {
        if (Tools::isSubmit('btnSubmit')) {
            Configuration::updateValue('WE_API_KEY', Tools::getValue('key'));
            $this->_html .= '<div class="conf confirm"> '.$this->l('Settings updated').'</div>';
        }
    }

    private function _displayWatcheezy()
    {
        $this->_html .= '<img src="../modules/targetfirst/logo_color.png" style="float:left; margin-right:15px;"><b>'.$this->l('Targetfirst improve the conversion rate thanks to face to face online customer support. Targetfirst brings human factor approach to video collaboration, which is key to convert a visitor into a customer.').'</b><br />';
        $this->_html .= '<div class="login clearfix"><h3>'.$this->l('Have you got your API key?').'</h3><br>';
        $this->_html .= '<a href="https://www.Targetfirst.com" target="_blank"><span id="targetfirst" class="getOneButton">'.$this->l('Get one').'</span></a></div>';
    }

    private function _displayForm()
    {
        $this->_html .=
        '<form id="targetfirstform" action="'.Tools::htmlentitiesUTF8($_SERVER['REQUEST_URI']).'" method="post">
            <fieldset>
            <legend><img src="../img/admin/contact.gif" />'.$this->l('Settings').'</legend>
                <table border="0" width="500" cellpadding="0" cellspacing="0" id="form">
                    <tr><td colspan="2">'.$this->l('Please specify the API key required to activate Targetfirst.').'<br /><br /></td></tr>
                    <tr><td width="130" style="height: 35px;">'.$this->l('API Key').'</td><td><input type="text" name="key" value="'.Tools::htmlentitiesUTF8(Tools::getValue('key', $this->api_key)).'" style="width: 300px;" /></td></tr>                
                    <tr><td colspan="2" align="center"><br /><input class="button" name="btnSubmit" value="'.$this->l('Update settings').'" type="submit" /></td></tr>
                </table>
            </fieldset>
        </form>';
    }
    
    public function getContent()
    {
        // Add default CSS
        $this->context->controller->addCSS($this->getPathUri() . 'views/css/targetfirst.css', 'all');
        $this->_html = '<div style="width: 960px; margin: 0 auto;">';

        if (Tools::isSubmit('btnSubmit')) {
            $this->_postValidation();
            if (!count($this->_postErrors)) {
                $this->_postProcess();
            } else {
                foreach ($this->_postErrors as $err) {
                    $this->_html .= '<div class="alert error">'.$err.'</div>';
                }
            }
        } else {
            $this->_html .= '<br>';
        }

        $this->_displayWatcheezy();
        $this->_displayForm();
        
        $this->_html .= '</div>';

        return $this->_html;
    }

    public function hookDisplayFooter($params)
    {
        if (!$this->active) {
            return;
        }
        
        if ($this->api_key) {
            $this->context->smarty->assign(array(
            'src_url' => $this->url.'?wzkey='.$this->api_key
            ));
            return $this->display(__FILE__, 'footer.tpl');
        }
    }
}
